=== modified file 'breezy/_export_c_api.h'
--- breezy/_export_c_api.h	2017-06-22 00:47:16 +0000
+++ breezy/_export_c_api.h	2017-06-27 00:10:52 +0000
@@ -15,8 +15,6 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-/* GZ 2017-06-22: This header needs updating to use Capsules over CObjects */
-
 /* This file contains helper functions for exporting a C API for a CPython
  * extension module.
  */
@@ -44,7 +42,7 @@
 _export_function(PyObject *module, char *funcname, void *func, char *signature)
 {
     PyObject *d = NULL;
-    PyObject *c_obj = NULL;
+    PyObject *capsule = NULL;
 
     d = PyObject_GetAttrString(module, _C_API_NAME);
     if (!d) {
@@ -56,15 +54,15 @@
         if (PyModule_AddObject(module, _C_API_NAME, d) < 0)
             goto bad;
     }
-    c_obj = PyCObject_FromVoidPtrAndDesc(func, signature, 0);
-    if (!c_obj)
+    capsule = PyCapsule_New(func, signature, 0);
+    if (!capsule)
         goto bad;
-    if (PyDict_SetItemString(d, funcname, c_obj) < 0)
+    if (PyDict_SetItemString(d, funcname, capsule) < 0)
         goto bad;
     Py_DECREF(d);
     return 0;
 bad:
-    Py_XDECREF(c_obj);
+    Py_XDECREF(capsule);
     Py_XDECREF(d);
     return -1;
 }

=== modified file 'breezy/_import_c_api.h'
--- breezy/_import_c_api.h	2009-10-12 21:44:27 +0000
+++ breezy/_import_c_api.h	2017-06-27 00:10:52 +0000
@@ -44,36 +44,28 @@
                             void **func, const char *signature)
 {
     PyObject *d = NULL;
-    PyObject *c_obj = NULL;
-    const char *desc = NULL;
+    PyObject *capsule = NULL;
+    void *pointer;
 
-    /* (char *) because Python2.4 defines this as (char *) rather than
-     * (const char *)
-     */
-    d = PyObject_GetAttrString(module, (char *)_C_API_NAME);
+    d = PyObject_GetAttrString(module, _C_API_NAME);
     if (!d) {
         // PyObject_GetAttrString sets an appropriate exception
         goto bad;
     }
-    c_obj = PyDict_GetItemString(d, funcname);
-    if (!c_obj) {
+    capsule = PyDict_GetItemString(d, funcname);
+    if (!capsule) {
         // PyDict_GetItemString does not set an exception
         PyErr_Format(PyExc_AttributeError,
             "Module %s did not export a function named %s\n",
             PyModule_GetName(module), funcname);
         goto bad;
     }
-    desc = (char *)PyCObject_GetDesc(c_obj);
-    if (!desc || strcmp(desc, signature) != 0) {
-        if (desc == NULL) {
-            desc = "<null>";
-        }
-        PyErr_Format(PyExc_TypeError,
-            "C function %s.%s has wrong signature (expected %s, got %s)",
-                PyModule_GetName(module), funcname, signature, desc);
+    pointer = PyCapsule_GetPointer(capsule, signature);
+    if (!pointer) {
+	// PyCapsule_GetPointer sets an error with a little context
         goto bad;
     }
-    *func = PyCObject_AsVoidPtr(c_obj);
+    *func = pointer;
     Py_DECREF(d);
     return 0;
 bad:

